@@ -378,20 +378,14 @@ class ChallengeResolveMixin:
                 elif "phone_number" in steps:
                     self._send_private_request(challenge_url, {"choice": CHOICE_SMS})
                 else:
-                    raise ChallengeError(
-                        'ChallengeResolve: Choice "email" or "phone_number" (sms) not available to this account %s'
-                        % self.last_json
-                    )
+                    raise ChallengeError(f'ChallengeResolve: Choice "email" or "phone_number" (sms) not available to this account {self.last_json}')
             wait_seconds = 5
             for attempt in range(24):
                 code = self.challenge_code_handler(self.username, CHOICE_EMAIL)
                 if code:
                     break
                 time.sleep(wait_seconds)
-            print(
-                'Enter code "%s" for %s (%d attempts by %d seconds)'
-                % (code, self.username, attempt, wait_seconds)
-            )
+            print(f'Code entered "{code}" for {self.username} ({attempt} attempts by {wait_seconds} seconds)')
             self._send_private_request(challenge_url, {"security_code": code})
             # assert 'logged_in_user' in client.last_json
             assert self.last_json.get("action", "") == "close"
@@ -401,9 +395,23 @@ class ChallengeResolveMixin:
             assert self.last_json.get("action", "") == "close"
             assert self.last_json.get("status", "") == "ok"
             return True
+        elif step_name == "change_password":
+            # Example: {'step_name': 'change_password',
+            #  'step_data': {'new_password1': 'None', 'new_password2': 'None'},
+            #  'flow_render_type': 3,
+            #  'bloks_action': 'com.instagram.challenge.navigation.take_challenge',
+            #  'cni': 18226879502000588,
+            #  'challenge_context': '{"step_name": "change_password", "cni": 18226879502000588, "is_stateless": false, "challenge_type_enum": "PASSWORD_RESET"}',
+            #  'challenge_type_enum_str': 'PASSWORD_RESET',
+            #  'status': 'ok'}
+            wait_seconds = 5
+            for attempt in range(24):
+                pwd = self.change_password_handler(self.username)
+                if pwd:
+                    break
+                time.sleep(wait_seconds)
+            print(f'Password entered "{pwd}" for {self.username} ({attempt} attempts by {wait_seconds} seconds)')
+            return self.bloks_change_password(pwd, self.last_json['challenge_context'])
         else:
-            raise Exception(
-                'ChallengeResolve: Unknown step_name "%s" for "%s" in challenge resolver: %s'
-                % (step_name, self.username, self.last_json)
-            )
+            raise Exception(f'ChallengeResolve: Unknown step_name "{step_name}" for "{self.username}" in challenge resolver: {self.last_json}')
         return True
