@@ -6,7 +6,6 @@ from .types import StoryBuild, StoryMention
 
 try:
     from moviepy.editor import CompositeVideoClip, ImageClip, TextClip, VideoFileClip
-    from moviepy.video.io.ffmpeg_tools import ffmpeg_extract_subclip
 except ImportError:
     raise Exception("Please install moviepy==1.0.3 and retry")
 
@@ -126,17 +125,19 @@ class StoryBuilder:
             mentions = [mention]
         duration = max_duration if max_duration else int(clip.duration)
         destination = tempfile.mktemp(".mp4")
-        CompositeVideoClip(clips, size=(self.width, self.height)).set_fps(
-            24
-        ).set_duration(duration).write_videofile(
-            destination, codec="libx264", audio=True, audio_codec="aac"
-        )
+        cvc = CompositeVideoClip(clips, size=(self.width, self.height))\
+            .set_fps(24)\
+            .set_duration(duration)
+        cvc.write_videofile(destination, codec="libx264", audio=True, audio_codec="aac")
         paths = []
         if duration > 15:
             for i in range(duration // 15 + (1 if duration % 15 else 0)):
                 path = tempfile.mktemp(".mp4")
                 start = i * 15
-                ffmpeg_extract_subclip(destination, start, start + 15, targetname=path)
+                rest = duration - start
+                end = start + (rest if rest < 15 else 15)
+                sub = cvc.subclip(start, end)
+                sub.write_videofile(path, codec="libx264", audio=True, audio_codec="aac")
                 paths.append(path)
         return StoryBuild(mentions=mentions, path=destination, paths=paths)
 
